@@ -24,7 +24,10 @@
 #                                                                              #
 ################################################################################
 
+import base64
+
 import github.GithubObject
+import github.Repository
 
 
 class ContentFile(github.GithubObject.CompletableGithubObject):
@@ -38,7 +41,12 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._content)
-        return self._NoneIfNotSet(self._content)
+        return self._content.value
+
+    @property
+    def decoded_content(self):
+        assert self.encoding == "base64", "unsupported encoding: %s" % self.encoding
+        return base64.b64decode(self.content)
 
     @property
     def encoding(self):
@@ -46,7 +54,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._encoding)
-        return self._NoneIfNotSet(self._encoding)
+        return self._encoding.value
 
     @property
     def git_url(self):
@@ -54,7 +62,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._git_url)
-        return self._NoneIfNotSet(self._git_url)
+        return self._git_url.value
 
     @property
     def html_url(self):
@@ -62,7 +70,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._html_url)
-        return self._NoneIfNotSet(self._html_url)
+        return self._html_url.value
 
     @property
     def name(self):
@@ -70,7 +78,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._name)
-        return self._NoneIfNotSet(self._name)
+        return self._name.value
 
     @property
     def path(self):
@@ -78,7 +86,18 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._path)
-        return self._NoneIfNotSet(self._path)
+        return self._path.value
+
+    @property
+    def repository(self):
+        """
+        :type: :class:`github.Repository.Repository`
+        """
+        if self._repository is github.GithubObject.NotSet:
+            # The repository was not set automatically, so it must be looked up by url.
+            repo_url = "/".join(self.url.split("/")[:6])
+            self._repository = github.GithubObject._ValuedAttribute(github.Repository.Repository(self._requester, self._headers, {'url': repo_url}, completed=False))
+        return self._repository.value
 
     @property
     def sha(self):
@@ -86,7 +105,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._sha)
-        return self._NoneIfNotSet(self._sha)
+        return self._sha.value
 
     @property
     def size(self):
@@ -94,7 +113,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: integer
         """
         self._completeIfNotSet(self._size)
-        return self._NoneIfNotSet(self._size)
+        return self._size.value
 
     @property
     def type(self):
@@ -102,7 +121,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._type)
-        return self._NoneIfNotSet(self._type)
+        return self._type.value
 
     @property
     def url(self):
@@ -110,7 +129,7 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         :type: string
         """
         self._completeIfNotSet(self._url)
-        return self._NoneIfNotSet(self._url)
+        return self._url.value
 
     def _initAttributes(self):
         self._content = github.GithubObject.NotSet
@@ -119,38 +138,31 @@ class ContentFile(github.GithubObject.CompletableGithubObject):
         self._html_url = github.GithubObject.NotSet
         self._name = github.GithubObject.NotSet
         self._path = github.GithubObject.NotSet
+        self._repository = github.GithubObject.NotSet
         self._sha = github.GithubObject.NotSet
         self._size = github.GithubObject.NotSet
         self._type = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "content" in attributes:  # pragma no branch
-            assert attributes["content"] is None or isinstance(attributes["content"], (str, unicode)), attributes["content"]
-            self._content = attributes["content"]
+            self._content = self._makeStringAttribute(attributes["content"])
         if "encoding" in attributes:  # pragma no branch
-            assert attributes["encoding"] is None or isinstance(attributes["encoding"], (str, unicode)), attributes["encoding"]
-            self._encoding = attributes["encoding"]
+            self._encoding = self._makeStringAttribute(attributes["encoding"])
         if "git_url" in attributes:  # pragma no branch
-            assert attributes["git_url"] is None or isinstance(attributes["git_url"], (str, unicode)), attributes["git_url"]
-            self._git_url = attributes["git_url"]
+            self._git_url = self._makeStringAttribute(attributes["git_url"])
         if "html_url" in attributes:  # pragma no branch
-            assert attributes["html_url"] is None or isinstance(attributes["html_url"], (str, unicode)), attributes["html_url"]
-            self._html_url = attributes["html_url"]
+            self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "name" in attributes:  # pragma no branch
-            assert attributes["name"] is None or isinstance(attributes["name"], (str, unicode)), attributes["name"]
-            self._name = attributes["name"]
+            self._name = self._makeStringAttribute(attributes["name"])
         if "path" in attributes:  # pragma no branch
-            assert attributes["path"] is None or isinstance(attributes["path"], (str, unicode)), attributes["path"]
-            self._path = attributes["path"]
+            self._path = self._makeStringAttribute(attributes["path"])
+        if "repository" in attributes:  # pragma no branch
+            self._repository = self._makeClassAttribute(github.Repository.Repository, attributes["repository"])
         if "sha" in attributes:  # pragma no branch
-            assert attributes["sha"] is None or isinstance(attributes["sha"], (str, unicode)), attributes["sha"]
-            self._sha = attributes["sha"]
+            self._sha = self._makeStringAttribute(attributes["sha"])
         if "size" in attributes:  # pragma no branch
-            assert attributes["size"] is None or isinstance(attributes["size"], (int, long)), attributes["size"]
-            self._size = attributes["size"]
+            self._size = self._makeIntAttribute(attributes["size"])
         if "type" in attributes:  # pragma no branch
-            assert attributes["type"] is None or isinstance(attributes["type"], (str, unicode)), attributes["type"]
-            self._type = attributes["type"]
+            self._type = self._makeStringAttribute(attributes["type"])
         if "url" in attributes:  # pragma no branch
-            assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
-            self._url = attributes["url"]
+            self._url = self._makeStringAttribute(attributes["url"])
