@@ -4,6 +4,7 @@
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Bill Mill <bill.mill@gmail.com>                               #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2013 davidbrai <davidbrai@gmail.com>                               #
@@ -44,7 +45,7 @@ class PaginatedListBase:
         for element in self.__elements:
             yield element
         while self._couldGrow():
-            newElements = self.__grow()
+            newElements = self._grow()
             for element in newElements:
                 yield element
 
@@ -53,9 +54,9 @@ class PaginatedListBase:
 
     def __fetchToIndex(self, index):
         while len(self.__elements) <= index and self._couldGrow():
-            self.__grow()
+            self._grow()
 
-    def __grow(self):
+    def _grow(self):
         newElements = self._fetchNextPage()
         self.__elements += newElements
         return newElements
@@ -116,9 +117,21 @@ class PaginatedList(PaginatedListBase):
         if self.__requester.per_page != 30:
             self.__nextParams["per_page"] = self.__requester.per_page
         self._reversed = False
+        self.__totalCount = None
+
+    @property
+    def totalCount(self):
+        if not self.__totalCount:
+            self._grow()
+
+        return self.__totalCount
 
     def _getLastPageUrl(self):
-        headers, data = self.__requester.requestJsonAndCheck("GET", self.__firstUrl, self.__nextParams, None)
+        headers, data = self.__requester.requestJsonAndCheck(
+            "GET",
+            self.__firstUrl,
+            parameters=self.__nextParams
+        )
         links = self.__parseLinkHeader(headers)
         lastUrl = links.get("last")
         return lastUrl
@@ -139,7 +152,11 @@ class PaginatedList(PaginatedListBase):
         return self.__nextUrl is not None
 
     def _fetchNextPage(self):
-        headers, data = self.__requester.requestJsonAndCheck("GET", self.__nextUrl, self.__nextParams, None)
+        headers, data = self.__requester.requestJsonAndCheck(
+            "GET",
+            self.__nextUrl,
+            parameters=self.__nextParams
+        )
 
         self.__nextUrl = None
         if len(data) > 0:
@@ -151,8 +168,12 @@ class PaginatedList(PaginatedListBase):
                 self.__nextUrl = links["next"]
         self.__nextParams = None
 
+        if 'items' in data:
+            self.__totalCount = data['total_count']
+            data = data["items"]
+
         content = [
-            self.__contentClass(self.__requester, element, completed=False)
+            self.__contentClass(self.__requester, headers, element, completed=False)
             for element in data
         ]
         if self._reversed:
@@ -176,9 +197,17 @@ class PaginatedList(PaginatedListBase):
             params["page"] = page + 1
         if self.__requester.per_page != 30:
             params["per_page"] = self.__requester.per_page
-        headers, data = self.__requester.requestJsonAndCheck("GET", self.__firstUrl, params, None)
+        headers, data = self.__requester.requestJsonAndCheck(
+            "GET",
+            self.__firstUrl,
+            parameters=params
+        )
+
+        if 'items' in data:
+            self.__totalCount = data['total_count']
+            data = data["items"]
 
         return [
-            self.__contentClass(self.__requester, element, completed=False)
+            self.__contentClass(self.__requester, headers, element, completed=False)
             for element in data
         ]
